﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Net;
using System.Text;
using System.IO;
using System.Xml;
using System.Configuration;

namespace Memory_Giving_API_Examples
{
    public class HttpRequest
    {
        public static XmlDocument Execute(String opperation, String postData)
        {
            // Create a request using a URL that can receive a post.
            WebRequest request = WebRequest.Create(ConfigurationManager.AppSettings["Host"].ToString() + ConfigurationManager.AppSettings["WebService"].ToString() + "/" + opperation);
            // Set the Method property of the request to POST.
            request.Method = "POST";
            // Convert POST data to a byte array.
            byte[] byteArray = Encoding.UTF8.GetBytes(postData);
            // Set the ContentType property of the WebRequest.
            request.ContentType = "application/x-www-form-urlencoded";
            // Set the ContentLength property of the WebRequest.
            request.ContentLength = byteArray.Length;
            // Get the request stream.
            Stream dataStream = request.GetRequestStream();
            // Write the data to the request stream.
            dataStream.Write(byteArray, 0, byteArray.Length);
            // Close the Stream object.
            dataStream.Close();
            // Get the response.
            WebResponse response = request.GetResponse();
            // Get the stream containing content returned by the server.
            dataStream = response.GetResponseStream();
            // Open the stream using a StreamReader for easy access.
            StreamReader reader = new StreamReader(dataStream);
            // Read the content.
            string responseFromServer = reader.ReadToEnd();

            // Clean up the streams.
            reader.Close();
            dataStream.Close();
            response.Close();

            XmlDocument xmlresponse = new XmlDocument();
            xmlresponse.LoadXml(responseFromServer);

            return xmlresponse;
        }

        public enum SoapVersion
        {
            SOAP = 11,
            SOAP12 = 12
        };

        public static XmlDocument ExecuteSOAP(String opperation, String SOAPData, SoapVersion ver)
        {
            var _url    = ConfigurationManager.AppSettings["Host"].ToString() + ConfigurationManager.AppSettings["WebService"].ToString();
            var _action = "http://memorygiving.com/" + ConfigurationManager.AppSettings["WebService"].ToString() + "/" + opperation;

            XmlDocument soapEnvelopeXml = CreateSoapEnvelope(opperation, SOAPData, ver);
            HttpWebRequest webRequest = CreateWebRequest(_url, _action, ver);
            InsertSoapEnvelopeIntoWebRequest(soapEnvelopeXml, webRequest);

            // begin async call to web request.
            IAsyncResult asyncResult = webRequest.BeginGetResponse(null, null);

            // suspend this thread until call is complete.
            asyncResult.AsyncWaitHandle.WaitOne();

            // get the response from the completed web request.
            string soapResult;
            using (WebResponse webResponse = webRequest.EndGetResponse(asyncResult))
            {
                using (StreamReader rd = new StreamReader(webResponse.GetResponseStream()))
                {
                    soapResult = rd.ReadToEnd();
                }
                
                XmlDocument xmlresponse = new XmlDocument();
                xmlresponse.LoadXml(soapResult);

                return xmlresponse;
            }
        }

        private static HttpWebRequest CreateWebRequest(string url, string action, SoapVersion ver)
        {
            HttpWebRequest webRequest = (HttpWebRequest)WebRequest.Create(url);

            if (ver == SoapVersion.SOAP)
            {   //soap 1.1
                webRequest.Headers.Add("SOAPAction", action);
                webRequest.ContentType = "text/xml;charset=\"utf-8\"";
            }
            else
            {
                // soap 1.2
                webRequest.ContentType = "application/soap+xml;charset=\"utf-8\"";
            }
            webRequest.Accept = "text/xml";
            webRequest.Method = "POST";
            return webRequest;
        }

        private static XmlDocument CreateSoapEnvelope(String operation, String SOAPData, SoapVersion ver)
        {
            XmlDocument soapEnvelop = new XmlDocument();

            SOAPData = SOAPData.Replace("&", "&amp;");

            if (ver == SoapVersion.SOAP)
            {
                soapEnvelop.LoadXml(string.Format(@"<soap:Envelope xmlns:xsi=""http://www.w3.org/2001/XMLSchema-instance"" xmlns:xsd=""http://www.w3.org/2001/XMLSchema"" xmlns:soap=""http://schemas.xmlsoap.org/soap/envelope/""><soap:Body><{0} xmlns=""http://memorygiving.com/{2}"">{1}</{0}></soap:Body></soap:Envelope>"
                    , operation
                    , SOAPData
                    , ConfigurationManager.AppSettings["WebService"].ToString()));

            }
            else
            {                                                                                                                                                       //WSDL http://www.w3.org/2003/05/soap-envelope
                                                                                                                                                                   //http://schemas.xmlsoap.org/soap/envelope/

                soapEnvelop.LoadXml(string.Format(@"<soap12:Envelope xmlns:xsi=""http://www.w3.org/2001/XMLSchema-instance"" xmlns:xsd=""http://www.w3.org/2001/XMLSchema"" xmlns:soap12=""http://www.w3.org/2003/05/soap-envelope""><soap12:Body><{0}    xmlns=""http://memorygiving.com/{2}"">{1}</{0}></soap12:Body></soap12:Envelope>"
                    , operation
                    , SOAPData
                    , ConfigurationManager.AppSettings["WebService"].ToString()));
            }
            return soapEnvelop;
        }

        private static void InsertSoapEnvelopeIntoWebRequest(XmlDocument soapEnvelopeXml, HttpWebRequest webRequest)
        {
            using (Stream stream = webRequest.GetRequestStream())
            {
                soapEnvelopeXml.Save(stream);
            }
        }

        public static XmlDocument MakeRequest(String requestUriString, String postData)
        {
            // Create a request using a URL that can receive a post.
            WebRequest request = WebRequest.Create(requestUriString);
            // Set the Method property of the request to POST.
            request.Method = "POST";
            // Convert POST data to a byte array.
            byte[] byteArray = Encoding.UTF8.GetBytes(postData);
            // Set the ContentType property of the WebRequest.
            request.ContentType = "application/x-www-form-urlencoded";
            // Set the ContentLength property of the WebRequest.
            request.ContentLength = byteArray.Length;
            // Get the request stream.
            Stream dataStream = request.GetRequestStream();
            // Write the data to the request stream.
            dataStream.Write(byteArray, 0, byteArray.Length);
            // Close the Stream object.
            dataStream.Close();
            // Get the response.
            WebResponse response = request.GetResponse();
            // Get the stream containing content returned by the server.
            dataStream = response.GetResponseStream();
            // Open the stream using a StreamReader for easy access.
            StreamReader reader = new StreamReader(dataStream);
            // Read the content.
            string responseFromServer = reader.ReadToEnd();

            // Clean up the streams.
            reader.Close();
            dataStream.Close();
            response.Close();

            XmlDocument xmlresponse = new XmlDocument();
            xmlresponse.LoadXml(responseFromServer);

            return xmlresponse;
        }
    }
}