﻿using System;
using System.Configuration;
using System.Xml;
using System.Web;
using System.Web.UI.WebControls;

namespace Memory_Giving_API_Examples
{
    public partial class getRecentlyUpdatedCharities : System.Web.UI.Page
    {
        protected const string operation = "getRecentlyUpdatedCharities";

        protected string Data
        {
            get
            {
                return                                  "api_key="          + HttpUtility.UrlEncode(txt_api_key.Text)               +
                        (txt_datetime.Text      != "" ? "&datetime="        + HttpUtility.UrlEncode(txt_datetime.Text)      : "")   +
                        (txt_days.Text          != "" ? "&days="            + HttpUtility.UrlEncode(txt_days.Text)          : "")   +
                        (txt_page_number.Text   != "" ? "&page_number="     + HttpUtility.UrlEncode(txt_page_number.Text)   : "")   +
                        (txt_page_size.Text     != "" ? "&page_size="       + HttpUtility.UrlEncode(txt_page_size.Text)     : "");
            }
        }

        protected string SOAPData
        {
            get
            {
                return                                  "<api_key>"         + txt_api_key.Text      + "</api_key>"                  +
                        (txt_datetime.Text      != "" ? "<datetime>"        + txt_datetime.Text     + "</datetime>"         : "")   +
                        (txt_days.Text          != "" ? "<days>"            + txt_days.Text         + "</days>"             : "")   +
                        (txt_page_number.Text   != "" ? "<page_number>"     + txt_page_number.Text  + "</page_number>"      : "")   +
                        (txt_page_size.Text     != "" ? "<page_size>"       + txt_page_size.Text    + "</page_size>"        : "");
            }
        }
        
        protected void Page_Init(object sender, EventArgs e)
        {
            litTitle.Text   =
            litHeading.Text = operation;

            txt_api_key.Text        = ConfigurationManager.AppSettings["APIKey"].ToString();
            txt_datetime.Text       = DateTime.Now.ToString("dd MMMM yyyy HH:mm:ss");
            txt_days.Text           = "";
            txt_page_number.Text    = "";
            txt_page_size.Text      = "";
        }

        protected void DoGet(Object sender, EventArgs e)
        {
            Response.Redirect(ConfigurationManager.AppSettings["Host"].ToString() + ConfigurationManager.AppSettings["WebService"].ToString() + "/" + operation + "?" + Data);
        }

        protected void DoPost(Object sender, EventArgs e)
        {
            ErrorPanel.Visible =
            ResultPanel.Visible = false;
            
            try
            {
                XmlDocument xmlResponse = HttpRequest.Execute(operation, Data);

                PopulateResponseData(xmlResponse.DocumentElement);
            }
            catch (Exception ex)
            {
                ErrorSeverity.Text = "";
                ErrorInternalMessage.Text = ex.Message;
                ErrorFriendlyMessage.Text = "";

                ErrorPanel.Visible = true;
            }
        }

        protected void DoSOAP(Object sender, EventArgs e)
        {
            ErrorPanel.Visible =
            ResultPanel.Visible = false;
            try
            {
                HttpRequest.SoapVersion ver = ((LinkButton)sender).ID == "lbtnSOAP11" ? HttpRequest.SoapVersion.SOAP : HttpRequest.SoapVersion.SOAP12;
                XmlDocument xmlResponse = HttpRequest.ExecuteSOAP(operation, SOAPData, ver);

                PopulateResponseData(xmlResponse.DocumentElement["soap:Body"][operation + "Response"][operation + "Result"]);
            }
            catch (Exception ex)
            {
                ErrorSeverity.Text = "";
                ErrorInternalMessage.Text = ex.Message;
                ErrorFriendlyMessage.Text = "";

                ErrorPanel.Visible = true;
            }
        }

        protected void PopulateResponseData(XmlElement responseNode)
        {
            if (responseNode["Error"] == null)
            {
                search_results.DataSource   = responseNode.GetElementsByTagName("CharitySummary");
                search_results.DataBind();

                ResultPanel.Visible         = true;
            }
            else
            {
                ErrorSeverity.Text          = responseNode["Error"]["Severity"].InnerText;
                ErrorInternalMessage.Text   = responseNode["Error"]["InternalMessage"].InnerText;
                ErrorFriendlyMessage.Text   = responseNode["Error"]["FriendlyMessage"].InnerText;

                ErrorPanel.Visible          = true;
            }
        }

        protected void BindSearchResults(Object sender, RepeaterItemEventArgs e)
        {
            XmlNode xmlNode                     = (XmlNode)e.Item.DataItem;

            Literal litId                       = (Literal)e.Item.FindControl("litId");
            Literal litName                     = (Literal)e.Item.FindControl("litName");
            Literal litAliases                  = (Literal)e.Item.FindControl("litAliases");
            Literal litNumber                   = (Literal)e.Item.FindControl("litNumber");
            Literal litAddress1                 = (Literal)e.Item.FindControl("litAddress1");
            Literal litAddress2                 = (Literal)e.Item.FindControl("litAddress2");
            Literal litTown                     = (Literal)e.Item.FindControl("litTown");
            Literal litPostcode                 = (Literal)e.Item.FindControl("litPostcode");
            Literal litCountry                  = (Literal)e.Item.FindControl("litCountry");
            Literal litContactName              = (Literal)e.Item.FindControl("litContactName");
            Literal litContactEmail             = (Literal)e.Item.FindControl("litContactEmail");
            Literal litContactTelephone         = (Literal)e.Item.FindControl("litContactTelephone");
            Literal litIsActivated              = (Literal)e.Item.FindControl("litIsActivated");
            Literal litIsVisible                = (Literal)e.Item.FindControl("litIsVisible");
            Literal litIsDeleted                = (Literal)e.Item.FindControl("litIsDeleted");
            Literal litDateLastUpdated          = (Literal)e.Item.FindControl("litDateLastUpdated");            
            Image   imgLogoPath                 = (Image)e.Item.FindControl("imgLogoPath");


            litId.Text                  = xmlNode["ID"].InnerText;
            litName.Text                = xmlNode["Name"].InnerText;            
            litAliases.Text             = xmlNode["Aliases"].InnerText;         
            litNumber.Text              = xmlNode["Number"].InnerText;
            
            litAddress1.Text            = xmlNode["Address1"].InnerText;
            litAddress2.Text            = xmlNode["Address2"].InnerText;
            litTown.Text                = xmlNode["Town"].InnerText;
            litPostcode.Text            = xmlNode["Postcode"].InnerText;
            litCountry.Text             = xmlNode["Country"].InnerText;
            litContactName.Text         = xmlNode["ContactName"].InnerText;
            litContactEmail.Text        = xmlNode["ContactEmail"].InnerText;
            litContactTelephone.Text    = xmlNode["ContactTelephone"].InnerText;
            litIsActivated.Text         = xmlNode["IsActivated"].InnerText;
            litIsVisible.Text           = xmlNode["IsVisible"].InnerText;
            litIsDeleted.Text           = xmlNode["IsDeleted"].InnerText;
            litDateLastUpdated.Text     = xmlNode["DateLastUpdated"].InnerText;
            imgLogoPath.ImageUrl        = xmlNode["LogoPath"].InnerText;
        }
    }
}