﻿using System;
using System.Configuration;
using System.Xml;
using System.Web;
using System.Web.UI.WebControls;

namespace Memory_Giving_API_Examples
{
    public partial class loadTributeByPageName : System.Web.UI.Page
    {
        protected const string operation = "loadTributeByPageName";
        
        protected string Data
        {
            get
            {
                return                                  "api_key="      + HttpUtility.UrlEncode(txt_api_key.Text)       +
                        (txt_page_name.Text    != "" ?  "&page_name="   + HttpUtility.UrlEncode(txt_page_name.Text)    : "");
            }
        }
        
        protected string SOAPData
        {
            get
            {
                return                                  "<api_key>"     + txt_api_key.Text          + "</api_key>" +
                        (txt_page_name.Text    != "" ?  "<page_name>"   + txt_page_name.Text        + "</page_name>" : "");
            }
        }

        protected void Page_Init(object sender, EventArgs e)
        {
            txt_api_key.Text = ConfigurationManager.AppSettings["APIKey"].ToString();

            if (!IsPostBack)
            {
                string query_string_page_name = Request.QueryString["page_name"];
                if (!string.IsNullOrEmpty(query_string_page_name) && !string.IsNullOrWhiteSpace(query_string_page_name))
                {
                    txt_page_name.Text = query_string_page_name;
                    DoPost(sender, e);
                }
            }
        }

        protected void DoGet(Object sender, EventArgs e)
        {
            Response.Redirect(ConfigurationManager.AppSettings["Host"].ToString() + ConfigurationManager.AppSettings["WebService"].ToString() + "/" + operation + "?" + Data);
        }

        protected void DoPost(Object sender, EventArgs e)
        {
            ErrorPanel.Visible =
            ResultPanel.Visible = false;

            try
            {
                XmlDocument xmlResponse = HttpRequest.Execute(operation, Data);

                PopulateResponseData(xmlResponse.DocumentElement);
            }
            catch (Exception ex)
            {
                ErrorSeverity.Text = "";
                ErrorInternalMessage.Text = ex.Message;
                ErrorFriendlyMessage.Text = "";

                ErrorPanel.Visible = true;
            }
        }

        protected void DoSOAP(Object sender, EventArgs e)
        {
            ErrorPanel.Visible =
            ResultPanel.Visible = false;
            try
            {
                HttpRequest.SoapVersion ver = ((LinkButton)sender).ID == "lbtnSOAP11" ? HttpRequest.SoapVersion.SOAP : HttpRequest.SoapVersion.SOAP12;
                XmlDocument xmlResponse = HttpRequest.ExecuteSOAP(operation, SOAPData, ver);

                PopulateResponseData(xmlResponse.DocumentElement["soap:Body"][operation + "Response"][operation + "Result"]);
            }
            catch (Exception ex)
            {
                ErrorSeverity.Text = "";
                ErrorInternalMessage.Text = ex.Message;
                ErrorFriendlyMessage.Text = "";

                ErrorPanel.Visible = true;
            }
        }

        protected void PopulateResponseData(XmlElement responseNode)
        {
            if (responseNode["Error"] == null)
            {
                
                id.Text                             = responseNode["Data"]["id"].InnerText;
                page_name.Text                      = responseNode["Data"]["page_name"].InnerText;
                aliases.Text                        = responseNode["Data"]["aliases"].InnerText;
                name.Text                           = responseNode["Data"]["name"].InnerText;
                if (!responseNode["Data"]["age"].IsEmpty)
                {
                    age.Text = responseNode["Data"]["age"].InnerText;
                }
                else
                {
                    age.Text = "";
                }
                if (!responseNode["Data"]["age_unit"].IsEmpty)
                {
                    age_unit.Text = responseNode["Data"]["age_unit"].InnerText;
                }
                else
                {
                    age_unit.Text = "";
                }
                DoDMessage.Text = responseNode["Data"]["DoDMessage"].InnerText;
                cropped_photo_path.ImageUrl         = "http://" + responseNode["Data"]["cropped_photo_path"].InnerText;
                cropped_photo_thumb_path.ImageUrl   = "http://" + responseNode["Data"]["cropped_photo_thumb_path"].InnerText;
                colour.Text                         = responseNode["Data"]["colour"].InnerText;
                date_of_death.Text                  = responseNode["Data"]["date_of_death"].InnerText;
                facebook_link.Text                  = responseNode["Data"]["facebook_link"].InnerText;
                message.Text                        = responseNode["Data"]["message"].InnerText;
                date_created.Text                   = responseNode["Data"]["date_created"].InnerText;
                if (responseNode["Data"]["date_closed"] != null)
                {
                    date_closed.Text = responseNode["Data"]["date_closed"].InnerText;
                }
                donations_total.Text                = responseNode["Data"]["donations_total"].InnerText;
                donations_online_total.Text         = responseNode["Data"]["donations_online_total"].InnerText;
                donations_offline_total.Text        = responseNode["Data"]["donations_offline_total"].InnerText;
                gift_aid_total.Text                 = responseNode["Data"]["gift_aid_total"].InnerText;

                #region Event Fields that are being phased out
                service_published.Text              = responseNode["Data"]["service_display"].InnerText;
                service_date_time.Text              = responseNode["Data"]["service_date_time"].InnerText;
                service_address_prefix.Text         = responseNode["Data"]["service_chapel"].InnerText;
                service_address.Text                = responseNode["Data"]["service_address"].InnerText;
                service_location.Text               = responseNode["Data"]["service_location"].InnerText;
                service_notes.Text                  = responseNode["Data"]["service_notes"].InnerText;

                committal_published.Text            = responseNode["Data"]["committal_display"].InnerText;
                committal_address.Text              = responseNode["Data"]["committal_address"].InnerText;
                committal_location.Text             = responseNode["Data"]["committal_location"].InnerText;

                reception_published.Text            = responseNode["Data"]["reception_display"].InnerText;
                reception_date_time.Text            = responseNode["Data"]["reception_date_time"].InnerText;
                reception_address.Text              = responseNode["Data"]["reception_address"].InnerText;
                reception_location.Text             = responseNode["Data"]["reception_location"].InnerText;
                #endregion

                #region New Event Fields - Not available on the live site.
                if (responseNode["Data"]["events"] != null)
                { 
                    foreach (XmlNode xmlNode in responseNode["Data"]["events"].ChildNodes)
                    {
                        string type                                 = xmlNode["type"].InnerText;
                        string published                            = xmlNode["published"].InnerText;
                        string title                                = xmlNode["title"].InnerText;
                        string date_time                            = xmlNode["date_time"].InnerText;
                        string address_prefix                       = xmlNode["address_prefix"].InnerText;
                        string address                              = xmlNode["address"].InnerText;
                        string location                             = xmlNode["location"].InnerText;
                        string notes                                = xmlNode["notes"].InnerText;
                        string webcast                              = xmlNode["webcast"].InnerText;
                        string webcast_url                          = xmlNode["webcast_url"].InnerText;
                        string webcast_username                     = xmlNode["webcast_username"].InnerText;
                        string webcast_password                     = xmlNode["webcast_password"].InnerText;
                        string order_of_service_pdf                 = xmlNode["order_of_service_pdf"].InnerText;
                        string order_of_service_url                 = xmlNode["order_of_service_url"].InnerText;

                        switch (type)
                        {
                            case "Service":
                                service_published.Text                      = published;
                                service_title.Text                          = title;
                                service_date_time.Text                      = date_time;
                                service_address_prefix.Text                 = address_prefix;
                                service_address.Text                        = address;
                                service_location.Text                       = location;
                                service_notes.Text                          = notes;
                                service_webcast.Text                        = webcast;
                                service_webcast_url.Text                    = webcast_url;
                                service_webcast_username.Text               = webcast_username;
                                service_webcast_password.Text               = webcast_password;
                                service_order_of_service_pdf.Text           = order_of_service_pdf;
                                service_order_of_service_url.Text           = order_of_service_url;
                                break;
                            case "Committal":
                                committal_published.Text                    = published;
                                committal_title.Text                        = title;
                                committal_date_time.Text                    = date_time;
                                committal_address_prefix.Text               = address_prefix;
                                committal_address.Text                      = address;
                                committal_location.Text                     = location;
                                committal_notes.Text                        = notes;
                                committal_webcast.Text                      = webcast;
                                committal_webcast_url.Text                  = webcast_url;
                                committal_webcast_username.Text             = webcast_username;
                                committal_webcast_password.Text             = webcast_password;
                                break;
                            case "Reception":
                                reception_published.Text                    = published;
                                reception_title.Text                        = title;
                                reception_date_time.Text                    = date_time;
                                reception_address_prefix.Text               = address_prefix;
                                reception_address.Text                      = address;
                                reception_location.Text                     = location;
                                reception_notes.Text                        = notes;
                                reception_webcast.Text                      = webcast;
                                reception_webcast_url.Text                  = webcast_url;
                                reception_webcast_username.Text             = webcast_username;
                                reception_webcast_password.Text             = webcast_password;
                                break;
                        }
                    }
                }
                #endregion
                
                fd_id.Text                          = responseNode["Data"]["funeral_director"]["id"].InnerText;
                fd_company_name.Text                = responseNode["Data"]["funeral_director"]["company_name"].InnerText;
                fd_address1.Text                    = responseNode["Data"]["funeral_director"]["address1"].InnerText;
                fd_address2.Text                    = responseNode["Data"]["funeral_director"]["address2"].InnerText;
                fd_town.Text                        = responseNode["Data"]["funeral_director"]["town"].InnerText;
                fd_postcode.Text                    = responseNode["Data"]["funeral_director"]["postcode"].InnerText;
                fd_description.Text                 = responseNode["Data"]["funeral_director"]["description"].InnerText;
                fd_web.Text                         = responseNode["Data"]["funeral_director"]["web"].InnerText;
                fd_contact_first_name.Text          = responseNode["Data"]["funeral_director"]["contact_first_name"].InnerText;
                fd_contact_last_name.Text           = responseNode["Data"]["funeral_director"]["contact_last_name"].InnerText;
                fd_contact_email.Text               = responseNode["Data"]["funeral_director"]["contact_email"].InnerText;
                    
                fd_telephone_1_label.Text           = responseNode["Data"]["funeral_director"]["telephone_1_label"].InnerText;
                fd_telephone_1.Text                 = responseNode["Data"]["funeral_director"]["telephone_1"].InnerText;
                fd_telephone_2_label.Text           = responseNode["Data"]["funeral_director"]["telephone_2_label"].InnerText;
                fd_telephone_2.Text                 = responseNode["Data"]["funeral_director"]["telephone_2"].InnerText;

                fd_cropped_logo_path.ImageUrl       = "http://" + responseNode["Data"]["funeral_director"]["cropped_logo_path"].InnerText;
                fd_trade_body.Text                  = responseNode["Data"]["funeral_director"]["trade_body"].InnerText;
                
                
                charity_id.Text                     = responseNode["Data"]["charity"]["id"].InnerText;
                charity_charity_name.Text           = responseNode["Data"]["charity"]["charity_name"].InnerText;
                charity_aliases.Text                = responseNode["Data"]["charity"]["aliases"].InnerText;
                charity_charity_number.Text         = responseNode["Data"]["charity"]["charity_number"].InnerText;
                charity_description.Text            = responseNode["Data"]["charity"]["description"].InnerText;
                charity_web.Text                    = responseNode["Data"]["charity"]["web"].InnerText;
                charity_cropped_logo_path.ImageUrl  = "http://" + responseNode["Data"]["charity"]["cropped_logo_path"].InnerText;

                if (responseNode["Data"]["donations"] != null)
                {
                    SubResultsRepeater.DataSource   = responseNode["Data"]["donations"].ChildNodes;
                    SubResultsRepeater.DataBind();
                }
                ResultPanel.Visible                 = true;
            }
            else
            {
                ErrorSeverity.Text                  = responseNode["Error"]["Severity"].InnerText;
                ErrorInternalMessage.Text           = responseNode["Error"]["InternalMessage"].InnerText;
                ErrorFriendlyMessage.Text           = responseNode["Error"]["FriendlyMessage"].InnerText;

                ErrorPanel.Visible                  = true;
            }
        }

        protected void BindSubResults(Object sender, RepeaterItemEventArgs e)
        {
            XmlNode xmlNode                     = (XmlNode)e.Item.DataItem;

            Literal id                          = (Literal)e.Item.FindControl("id");
            Literal tribute_id                  = (Literal)e.Item.FindControl("tribute_id");
            Literal anonymous                   = (Literal)e.Item.FindControl("anonymous");
            Literal display_name                = (Literal)e.Item.FindControl("display_name");
            Literal message                     = (Literal)e.Item.FindControl("message");
            Literal donation                    = (Literal)e.Item.FindControl("donation");
            Literal hide_donation_value         = (Literal)e.Item.FindControl("hide_donation_value");
            Literal donation_online             = (Literal)e.Item.FindControl("donation_online");
            Literal gift_aid                    = (Literal)e.Item.FindControl("gift_aid");
            Literal date_donation               = (Literal)e.Item.FindControl("date_donation");
            Literal value_gift_aid              = (Literal)e.Item.FindControl("value_gift_aid");
            
            id.Text                             = xmlNode["id"].InnerText;
            tribute_id.Text                     = xmlNode["tribute_id"].InnerText;
            anonymous.Text                      = xmlNode["anonymous"].InnerText;
            display_name.Text                   = xmlNode["display_name"].InnerText;
            message.Text                        = xmlNode["message"].InnerText;
            donation.Text                       = xmlNode["donation"].InnerText;
            donation_online.Text                = xmlNode["donation_online"].InnerText;
            gift_aid.Text                       = xmlNode["gift_aid"].InnerText;
            date_donation.Text                  = xmlNode["date_donation"].InnerText;
            value_gift_aid.Text                 = xmlNode["value_gift_aid"].InnerText;

            bool hide_donation_val              = Convert.ToBoolean(xmlNode["hide_donation_value"].InnerText);
            hide_donation_value.Text            = hide_donation_val.ToString();

            if (hide_donation_val)
            {
                donation.Text                   += "(Donor has chosen to hide donation value)";
                value_gift_aid.Text             += "(Donor has chosen to hide donation value)";
            }
        }
    }
}